# Generated by Django 4.0.1 on 2022-02-09 22:54

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('med', '0005_rec_remove_assistant_role_user_is_receptionist_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='assistant',
            name='doctor',
            field=models.CharField(default='', max_length=30),
        ),
        migrations.AddField(
            model_name='assistant',
            name='dr',
            field=models.CharField(default='', max_length=30),
        ),
    ]
