# Generated by Django 4.0.1 on 2022-02-10 20:34

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('med', '0007_remove_assistant_doctor_remove_assistant_dr_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='patient',
            name='prix',
            field=models.DecimalField(decimal_places=2, default=0, max_digits=8),
        ),
    ]
