# Generated by Django 4.0.1 on 2022-02-10 21:40

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('med', '0008_patient_prix'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='user',
            name='age',
        ),
    ]
