# Generated by Django 4.0.1 on 2022-02-07 18:16

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('med', '0002_used_alter_rdv_prixprop'),
    ]

    operations = [
        migrations.AddField(
            model_name='patient',
            name='isop',
            field=models.BooleanField(default=False),
        ),
    ]
