# Generated by Django 4.0.1 on 2022-02-07 13:03

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('med', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='Used',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(default='', max_length=25)),
                ('type', models.CharField(default='', max_length=25)),
                ('quantity', models.IntegerField(default=1)),
                ('prix', models.FloatField(default=0)),
                ('total', models.FloatField(default=0)),
            ],
        ),
        migrations.AlterField(
            model_name='rdv',
            name='prixprop',
            field=models.DecimalField(decimal_places=2, default=0, max_digits=8),
        ),
    ]
