# Generated by Django 4.0.1 on 2022-02-09 22:33

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('med', '0004_remove_rdv_nature_remove_rdv_prixprop_patient_nature_and_more'),
    ]

    operations = [
        migrations.CreateModel(
            name='Rec',
            fields=[
                ('user', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, primary_key=True, serialize=False, to=settings.AUTH_USER_MODEL)),
            ],
        ),
        migrations.RemoveField(
            model_name='assistant',
            name='role',
        ),
        migrations.AddField(
            model_name='user',
            name='is_receptionist',
            field=models.BooleanField(default=False),
        ),
        migrations.AlterField(
            model_name='patient',
            name='casp',
            field=models.CharField(default='', max_length=15),
        ),
        migrations.AlterField(
            model_name='patient',
            name='cast',
            field=models.CharField(default='', max_length=15),
        ),
    ]
