# Generated by Django 4.0.1 on 2022-02-14 17:06

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('med', '0013_food_dt_medecines_dt_used_dt'),
    ]

    operations = [
        migrations.AlterField(
            model_name='patient',
            name='currentstate',
            field=models.CharField(default='', max_length=15),
        ),
    ]
