# Generated by Django 4.0.1 on 2022-02-07 21:49

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('med', '0003_patient_isop'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='rdv',
            name='nature',
        ),
        migrations.RemoveField(
            model_name='rdv',
            name='prixprop',
        ),
        migrations.AddField(
            model_name='patient',
            name='nature',
            field=models.CharField(default='', max_length=20),
        ),
        migrations.AddField(
            model_name='patient',
            name='prixprop',
            field=models.DecimalField(decimal_places=2, default=0, max_digits=8),
        ),
    ]
