# Generated by Django 4.0.1 on 2022-02-09 23:07

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('med', '0006_assistant_doctor_assistant_dr'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='assistant',
            name='doctor',
        ),
        migrations.RemoveField(
            model_name='assistant',
            name='dr',
        ),
        migrations.RemoveField(
            model_name='assistant',
            name='drid',
        ),
        migrations.AddField(
            model_name='assistant',
            name='drid',
            field=models.ManyToManyField(to='med.Dctr'),
        ),
    ]
